---
title: Contributor Ladder
toc_hide: true
status: Completed
menu:
  main:
    weight: 10
---

Hi there! 👋 Thanks for your interest in contributing to the CNCF Cloud Native Glossary project. 
Whether you contribute new terms, help localize the Glossary into your native language, 
or want to help others get started, there are many ways to become an active member of this community. 
This doc outlines the different contributor roles within the project and the responsibilities and privileges that come with them.

## 1. Contributors

The Glossary is for everyone. Anyone can become a Glossary contributor simply by contributing to the project. 
All contributors are expected to follow the [CNCF Code of Conduct](https://github.com/cncf/foundation/blob/main/code-of-conduct.md).

There are a variety of ways you can contribute to the project, including:

- **Content contributors**: everyone who improves existing terms or contributes new ones, 
- **Localization contributors**: those who help translate the glossary into another language,
- **Helpers**: anyone who helps others on GitHub, Slack, or wherever community members need support,
- **Ambassadors**: anyone who helps spread the word, educates the community on how to contribute and why they should do so. 

Contributors can have multiple roles or focus on one area only. 
**All these contributions are equally important** and help foster a thriving community. 
Please refer to the [How to Contribute](/contribute/) and [Style Guide](/style-guide/) for content and localization contributions.

## 2. Approvers

Approvers provide feedback on PRs and approve them. Any active contributor can become an approver (see [Becoming an approver](#becoming-an-approver)). 
The Glossary differentiates between two approvers: (1) approvers for the English Glossary and (2) approvers for localization teams.

Glossary approvers are expected to:

- Review PRs for technical accuracy, 
- Assign contributors issues and label them appropriately,
- Provide contributors with feedback and guide them when needed,
- Proofread and edit submissions.

If an approver is no longer interested in or cannot perform the above duties, they should let the maintainers know and step down.

### English Glossary Approvers

There are three types of approvers:

1) Approvers with a strong technical background,
2) Approvers with solid writing skills,
3) Approvers who are proficient in both. 

**Technical Approvers**: Individuals with a strong technical background can be approvers without having solid English writing skills. 
However, if they approve a PR on technical merit, they must ensure it is reviewed by an (editor) approver.

**Editors**: Editors proofread terms and ensure they are explained in simple language according to the Style Guide. 
If a term is heavily edited, the editor must request a technical approver to review it again to ensure the meaning wasn't altered.

### Localization Approvers

The Glossary also has localization approvers. These are approvers for one of the localization teams (teams translating the glossary). 
Localization approvers are only permitted to perform approver duties for their own team and have the ability to merge PRs to their dedicated development branch. 
Any localization approver can also become an approver for the English Glossary if they meet the requirements. 

### Becoming an Approver

Approver candidates should have a proven track record of submitting high-quality PRs and helping others get their PRs in a mergeable state. 
If their timezone permits, they should also regularly attend the [Glossary Working Group meetings](https://www.cncf.io/calendar/).

To become an approver, start by expressing interest to existing maintainers. 
Existing maintainers will then ask you to demonstrate the qualifications above by contributing PRs, doing reviews, and doing other such tasks under their guidance. 
After some time of working together, maintainers will decide whether to grant you approver status. 
This decision will be based on your demonstrated level of proficiency and responsiveness.

## 3. Maintainers

Maintainers are approvers who can also merge PRs. Anyone can become a Glossary maintainer (see [Becoming a maintainer](#becoming-a-maintainer)). 
There are certain expectations for maintainers, including:

- Be an active and responsive approver (see above),
- Help maintain the repository, including site configuration, permission, issue-template, GitHub workflow, among others,
- Monitor the Glossary Slack channels and help out whenever possible,
- Regularly attend the [Glossary Working Group meetings](https://www.cncf.io/calendar/) (if timezone permits)

If a maintainer is no longer interested in or cannot perform the duties listed above, they should move themselves to emeritus status.

### Becoming a Maintainer

Maintainers should have a proven track record of being successful approvers and submitting high-quality PRs. 
If their timezone permits, they should also regularly attend the Glossary Working Group meetings.

To become a maintainer, start by expressing interest to existing maintainers. 
Existing maintainers will then ask you to demonstrate the qualifications above by contributing PRs, doing reviews, and doing other such tasks under their guidance. 
After some time of working together, maintainers will decide whether to grant maintainer status. 
This decision will be based on demonstrated level of proficiency and responsiveness.

## 4. Community Managers

Community managers help foster a welcoming and engaging community. Any community member can become a community manager. They are expected to:

- Welcome new members and ensure they get the information they need,
- Help answer questions from the community or identify someone who can help,
- Moderate conversations on Slack.

### Become a Community Manager

Anyone can become a Glossary community manager. 
Community managers must have a solid understanding of the contribution and localization process and enjoy interacting and helping others. 
To become a community manager, start by expressing interest to existing maintainers. 
After an onboarding/trial period, maintainers will decide whether to grant community manager status based on performance. 

## Involuntary Removal

Involuntary removal of a contributor happens when responsibilities and requirements aren't met. 
This may include repeated patterns of inactivity, extended periods of inactivity, and/or a violation of the code of conduct. 
This process is important because it protects the community and its deliverables while also opening up opportunities for new contributors to step in.

## Stepping Down/Emeritus Process

If and when contributors' commitment levels change, contributors can consider stepping down (moving down the contributor ladder) vs. 
moving to emeritus status (completely stepping away from the project).

## Stepping Back Into a Role

If and when someone is available to step back into a previous contributor role, project leadership can arrange and consider this.
